==> driza-0.5.tar.gz: driza-0.5.0/Driza/interfaz.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
#
#Fichero manejador de ficheros
#Copyright (C) 2006  Inmaculada Luengo Merino, Néstor Arocha Rodríguez

#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

class InterfazFichero:
	""" Interfaz entre datos y ficheros. Permite cargar o guardar un objeto contenedorregvar en un fichero """

	def __init__(self):
		"""
		Inicializa el manejador de ficheros.
		Crea los objetos que se usaran para comprobar la extension de los archivos
		"""
		#VARIABLES PRIVADAS
		import re
		self.__regexp=re.compile('.*\.pkl$')

	#FUNCIONES PUBLICAS
	def __getitem__(self,fichero):
		"""obtiene un objeto de datos de un fichero y lo devuelve"""
		archivo = open(fichero, 'r')
		if self.__regexp.match(fichero):
			import pickle
			datos=pickle.load(archivo) 
		archivo.close
		return datos
			
	def __setitem__(self,fichero,datos):
		"""Guarda el contenido del objeto pasado en el fichero indicado"""
		archivo = open(fichero, 'w')
		if self.__regexp.match(fichero):
			import pickle
			pickle.dump(datos,archivo)
		archivo.close()
		


class ListaFicheros(list):
	"""
	Contenedor de la lista de ficheros. Funciona como cola LIFO, y hereda de list.
	El parametro pasado es la longitud de lista que se desea
	"""
	def __init__(self,n):
		#VARIABLES PRIVADAS
		self.__nelementos=n
		list.__init__(self)

	#FUNCIONES PUBLICAS
	def insert(self,elemento):
		"""Inserta un elemento, garantizando que siempre se va a colocar en el primer lugar"""
		if elemento in self:
			self.remove(elemento)
		list.insert(self,0,elemento)
		if len(self)>self.nelementos:
			self.pop()

# Elementos a configurar:

	#tmpdir: Guarda la ruta del directorio de trabajo
	#rdir:   Guarda la ruta del ejecutable de R
	#vsplash: boolean que dice si aparece la ventana splash o no
	#lfichero: Lista de ficheros

class InterfazConfig:
	"""
	Clase encargada de gestionar la configuración. Permite leer y guardar la configuración en ficheros.
	"""
	def __init__(self):
		"""
		Funcion de inicialización del manejador de configuración 
		"""
		import os
		#VARIABLES PRIVADAS
		self.__fichero=os.environ["HOME"]+"/.driza" #Lugar de la configuración por defecto

	#FUNCIONES PÚBLICAS
	def __getitem__(self,fichero):
		"""
		Definicion del operador [], devuelve la configuración que se encuentra en un fichero, y None si no puede abrirlo
		"""
		import pickle
		try:
			archivo=open(fichero,"r")
		except: #Archivo nuevo
			return None
		else:
			config=pickle.load(archivo)
			archivo.close()
			return config



	def __setitem__(self, fichero, config):
		"""
		Guarda la configuración en el fichero indicado.
		"""
		import pickle
		if config["primeravez"]:
			config["primeravez"]=False
		archivo=open(fichero,"w")
		pickle.dump(config,archivo)
		archivo.close()
	
	def load(self):
		"""
		Carga la configuración del fichero de configuración del programa, devolviendo la configuración por defecto si no la encuentra
		"""
		config= self.__getitem__(self.__fichero)
		if not config:
			config=self.__default()
			self.save(config)
			config["primeravez"]=True
		return config

	def save(self,config):
		"""
		Guarda los valores pasados en el fichero de configuración del programa
		"""
		self.__setitem__(self.__fichero,config)

	#FUNCIONES PRIVADAS

	def __default(self):
		"""
		Devuelve la lista de parámetros por defecto
		"""
		listaficheros=ListaFicheros(5)
		return {"tmpdir":"/tmp","rdir":"/usr/bin/R","lfichero":listaficheros,"vsplash":True,"primeravez":False}

==> driza-0.5.1.tar.gz: driza-0.5.1/Driza/interfaz.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
#
#Fichero manejador de ficheros
#Copyright (C) 2006  Inmaculada Luengo Merino, Néstor Arocha Rodríguez

#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

from rpy import *

class InterfazFichero:
	""" Interfaz entre datos y ficheros. Permite cargar o guardar un objeto contenedorregvar en un fichero. Se comunica con una interfazdatos """

	def __init__(self,interfazdatos):
		"""
		Inicializa el manejador de ficheros.
		Crea los objetos que se usaran para comprobar la extension de los archivos
		"""
		#VARIABLES PRIVADAS
		import re
		self.diccionario={}
		self.__id=interfazdatos
		self.__driza=re.compile('.*\.driza$')
		self.__spss=re.compile('.*\.dat$')
		self.__txt=re.compile('.*\.txt$')

	#FUNCIONES PUBLICAS
	def __getitem__(self,fichero):
		"""obtiene un objeto de datos de un fichero y lo devuelve"""
		self.load(fichero)
			
	def __setitem__(self,fichero,datos):
		"""Guarda el contenido del objeto pasado en el fichero indicado"""
		self.save(fichero,datos)
		
	def save(self,fichero,datos,tipo=None):
		archivo = open(fichero, 'w')
		if self.__driza.match(fichero):
			import pickle
			pickle.dump(datos,archivo)
		archivo.close()

	def load(self,fichero,tipo=None):
		archivo = open(fichero, 'r')
		if self.__driza.match(fichero):
			import pickle
			datos=pickle.load(archivo) 
			archivo.close
			self.__id.insertarestado(datos)
		elif self.__spss.match(fichero):
			pass
		elif self.__txt.match(fichero):
			self.__id.borrartodo()
			datos=r.read_table(fichero)
			for pareja in datos.items():
				self.__id.appVar(pareja[0],"Real")
				self.__id[self.__id.getVar(pareja[0])]=pareja[1]


class ListaFicheros(list):
	"""
	Contenedor de la lista de ficheros. Funciona como cola LIFO, y hereda de list.
	El parametro pasado es la longitud de lista que se desea
	"""
	def __init__(self,n):
		#VARIABLES PRIVADAS
		self.__nelementos=n
		list.__init__(self)

	#FUNCIONES PUBLICAS
	def insert(self,elemento):
		"""Inserta un elemento, garantizando que siempre se va a colocar en el primer lugar"""
		if elemento in self:
			self.remove(elemento)
		list.insert(self,0,elemento)
		if len(self)>self.nelementos:
			self.pop()

# Elementos a configurar:

	#tmpdir: Guarda la ruta del directorio de trabajo
	#rdir:   Guarda la ruta del ejecutable de R
	#vsplash: boolean que dice si aparece la ventana splash o no
	#lfichero: Lista de ficheros

class InterfazConfig:
	"""
	Clase encargada de gestionar la configuración. Permite leer y guardar la configuración en ficheros.
	"""
	def __init__(self):
		"""
		Funcion de inicialización del manejador de configuración 
		"""
		import os
		#VARIABLES PRIVADAS
		self.__fichero=os.environ["HOME"]+"/.driza" #Lugar de la configuración por defecto

	#FUNCIONES PÚBLICAS
	def __getitem__(self,fichero):
		"""
		Definicion del operador [], devuelve la configuración que se encuentra en un fichero, y None si no puede abrirlo
		"""
		import pickle
		try:
			archivo=open(fichero,"r")
		except: #Archivo nuevo
			return None
		else:
			config=pickle.load(archivo)
			archivo.close()
			return config



	def __setitem__(self, fichero, config):
		"""
		Guarda la configuración en el fichero indicado.
		"""
		import pickle
		if config["primeravez"]:
			config["primeravez"]=False
		archivo=open(fichero,"w")
		pickle.dump(config,archivo)
		archivo.close()
	
	def load(self):
		"""
		Carga la configuración del fichero de configuración del programa, devolviendo la configuración por defecto si no la encuentra
		"""
		config= self.__getitem__(self.__fichero)
		if not config:
			config=self.__default()
			self.save(config)
			config["primeravez"]=True
		return config

	def save(self,config):
		"""
		Guarda los valores pasados en el fichero de configuración del programa
		"""
		self.__setitem__(self.__fichero,config)

	#FUNCIONES PRIVADAS

	def __default(self):
		"""
		Devuelve la lista de parámetros por defecto
		"""
		listaficheros=ListaFicheros(5)
		return {"tmpdir":"/tmp","rdir":"/usr/bin/R","lfichero":listaficheros,"vsplash":True,"primeravez":False}
